@@ -2,7 +2,7 @@
 /**
  * The Kolab implementation of free/busy.
  *
- * $Horde: framework/Kolab_FreeBusy/lib/Horde/Kolab/FreeBusy.php,v 1.10.2.4 2010-10-10 18:37:56 wrobel Exp $
+ * $Horde: framework/Kolab_FreeBusy/lib/Horde/Kolab/FreeBusy.php,v 1.10.2.10 2011/07/25 03:55:18 wrobel Exp $
  *
  * @package Kolab_FreeBusy
  */
@@ -19,6 +19,7 @@ require_once 'Horde/Kolab/FreeBusy/Access.php';
 require_once 'Horde/Kolab/FreeBusy/Exception.php';
 
 require_once 'Horde/iCalendar.php';
+require_once 'Horde/iCalendar/vfreebusy.php';
 
 /**
  * How to use this class
@@ -33,7 +34,7 @@ require_once 'Horde/iCalendar.php';
  *
  * $fb->fetch();
  *
- * $Horde: framework/Kolab_FreeBusy/lib/Horde/Kolab/FreeBusy.php,v 1.10.2.4 2010-10-10 18:37:56 wrobel Exp $
+ * $Horde: framework/Kolab_FreeBusy/lib/Horde/Kolab/FreeBusy.php,v 1.10.2.10 2011/07/25 03:55:18 wrobel Exp $
  *
  * Copyright 2004-2008 Klarälvdalens Datakonsult AB
  *
@@ -70,19 +71,20 @@ class Horde_Kolab_FreeBusy {
     /**
      * Trigger regeneration of free/busy data in a calender.
      */
-    function &trigger()
+    function trigger()
     {
         global $conf;
 
-        /* Get the folder name */
-        list($user, $owner, $folder) = $this->_getAccess();
-
         try {
+            /* Get the folder name */
+            list($user, $owner, $folder) = $this->_getAccess();
+            $db_owner = $this->_getDbOwner();
+
             Horde::logMessage(
                 sprintf(
-                    "Partial free/busy data for folder %s of owner %s requested by user %s.",
+                    "Partial free/busy data for folder \"%s\" of owner \"%s\" requested by user \"%s\".",
                     $folder->getFolder(),
-                    $owner->getOwner(),
+                    $db_owner->getPrimaryId(),
                     $user->getId()
                 ), 
                 __FILE__,
@@ -90,13 +92,10 @@ class Horde_Kolab_FreeBusy {
                 PEAR_LOG_DEBUG
             );
         } catch (Horde_Kolab_FreeBusy_Exception $e) {
-            $error = array('type' => FREEBUSY_ERROR_NOTFOUND,
-                           'error' => $e);
-            $view = new Horde_Kolab_FreeBusy_View_error($error);
-            return $view;
+            $error = array('type' => FREEBUSY_ERROR_NOTFOUND, 'error' => $e);
+            return new Horde_Kolab_FreeBusy_View_error($error);
         }
 
-
         /* Get the cache request variables */
         $req_cache    = Util::getFormData('cache', false);
         $req_extended = Util::getFormData('extended', false);
@@ -110,7 +109,6 @@ class Horde_Kolab_FreeBusy {
             return $view;
         }
 
-        list($user, $owner, $folder) = $this->_getAccess();
         if (!$req_cache) {
             /* User wants to regenerate the cache */
             $db_user  = $this->_getDbUser();
@@ -161,7 +159,6 @@ class Horde_Kolab_FreeBusy {
         /* Load the cache data */
         $vfb = $this->_getCache()->loadPartial($this->_getDbUser(), $folder, $req_extended);
         if (is_a($vfb, 'PEAR_Error')) {
-            var_dump($vfb->getMessage());
             $error = array('type' => FREEBUSY_ERROR_NOTFOUND,
                            'error' => $vfb);
             $view = new Horde_Kolab_FreeBusy_View_error($error);
@@ -196,36 +193,48 @@ class Horde_Kolab_FreeBusy {
         Horde::logMessage(sprintf("Starting generation of free/busy data for user %s", 
                                   $req_owner), __FILE__, __LINE__, PEAR_LOG_DEBUG);
 
-        /* Validate folder access */
-        $access = &new Horde_Kolab_FreeBusy_Access();
-        $result = $access->parseOwner($req_owner);
-        if (is_a($result, 'PEAR_Error')) {
-            $error = array('type' => FREEBUSY_ERROR_NOTFOUND, 'error' => $result);
-            $view = new Horde_Kolab_FreeBusy_View_error($error);
-            return $view;
+        try {
+            /* Get the folder name */
+            list($user, $owner, $folder) = $this->_getAccess();
+
+            Horde::logMessage(
+                sprintf(
+                    "Free/busy data of owner \"%s\" requested by user \"%s\".",
+                    $owner->getOwner(),
+                    $user->getId()
+                ), 
+                __FILE__,
+                __LINE__,
+                PEAR_LOG_DEBUG
+            );
+        } catch (Horde_Kolab_FreeBusy_Exception $e) {
+            $error = array('type' => FREEBUSY_ERROR_NOTFOUND, 'error' => $e);
+            return new Horde_Kolab_FreeBusy_View_error($error);
         }
 
-        Horde::logMessage(sprintf("Free/busy data of owner %s on server %s requested by user %s.",
-                                  $access->owner, $access->freebusyserver, $access->user), 
-                          __FILE__, __LINE__, PEAR_LOG_DEBUG);
 
         $req_extended = Util::getFormData('extended', false);
 
         /* Try to fetch the data if it is stored on a remote server */
-        $result = $access->fetchRemote(false, $req_extended);
-        if (is_a($result, 'PEAR_Error')) {
-            $error = array('type' => FREEBUSY_ERROR_UNAUTHORIZED, 'error' => $result);
-            $view = new Horde_Kolab_FreeBusy_View_error($error);
-            return $view;
-        }
-
-        $result = $this->_getCache()->loadCombined(
-            $this->_getDbUser(), $req_extended
+        $result = $this->fetchRemote(
+            $owner, $user, null, false, $req_extended
         );
+        if (is_a($result, 'PEAR_Error')) {
+            $error = array('type' => FREEBUSY_ERROR_UNAUTHORIZED, 'error' => $result);
+            return new Horde_Kolab_FreeBusy_View_error($error);
+        }
+
+        try {
+            $result = $this->_getCache()->loadCombined(
+                $this->_getDbUser(), $req_extended
+            );
+        } catch (Horde_Kolab_FreeBusy_Exception $e) {
+            $error = array('type' => FREEBUSY_ERROR_NOTFOUND, 'error' => $e);
+            return new Horde_Kolab_FreeBusy_View_error($error);
+        }
         if (is_a($result, 'PEAR_Error')) {
             $error = array('type' => FREEBUSY_ERROR_NOTFOUND, 'error' => $result);
-            $view = new Horde_Kolab_FreeBusy_View_error($error);
-            return $view;
+            return new Horde_Kolab_FreeBusy_View_error($error);
         }
 
         Horde::logMessage("Delivering complete free/busy data.", __FILE__, __LINE__, PEAR_LOG_DEBUG);
@@ -248,7 +257,7 @@ class Horde_Kolab_FreeBusy {
         $access = &new Horde_Kolab_FreeBusy_Access();
         $result = $access->authenticated();
         if (is_a($result, 'PEAR_Error')) {
-            return $result->getMessage();
+            return $result;
         }
 
         /* Load the required Kolab libraries */ 
@@ -257,7 +266,7 @@ class Horde_Kolab_FreeBusy {
         $list = &Kolab_List::singleton();
         $calendars = $list->getByType('event');
         if (is_a($calendars, 'PEAR_Error')) {
-            return $calendars->getMessage();
+            return $calendars;
         }
 
         $lines = array();
@@ -283,8 +292,8 @@ class Horde_Kolab_FreeBusy {
                 $owner = $access->user;
                 unset($req_folder[0]);
             }
-
-            $trigger = $owner . ($domain ? '@' . $domain : '') . '/' . join('/', $req_folder);
+            $owner = $owner . ($domain ? '@' . $domain : '');
+            $trigger = $owner . '/' . join('/', $req_folder);
             $trigger = String::convertCharset($trigger, 'UTF7-IMAP', 'UTF-8');
 
             /* Validate folder access */
@@ -320,16 +329,20 @@ class Horde_Kolab_FreeBusy {
             }
 
             /* Update the cache */
-            $vCal = $this->_generate($this->_getResource());
-            if (is_a($vCal, 'PEAR_Error')) {
-                $reporter->failure($calendar->name, $vCal->getMessage());
+            try {
+                $vCal = $this->_generate($this->_getResource($trigger, $owner));
+            } catch (Horde_Kolab_FreeBusy_Exception $e) {
+                $reporter->failure($calendar->name, $e->getMessage());
                 continue;
             }
 
+            $folder = new Horde_Kolab_FreeBusy_Params_Freebusy_Folder_Named(
+                $trigger
+            );
             if (empty($vCal)) {
-                $result = $this->_getCache()->deletePartial($this->_getDbUser(), $folder);
+                $result = $this->_getCache($owner)->deletePartial($this->_getDbUser(), $folder);
             } else {
-                $result = $this->_getCache()->storePartial($this->_getDbUser(), $folder, $vCal, $this->_getResource());
+                $result = $this->_getCache($owner)->storePartial($this->_getDbUser(), $folder, $this->_getResource($trigger, $owner), $vCal);
             }
             if (is_a($result, 'PEAR_Error')) {
                 $reporter->failure($calendar->name, $result->getMessage());
@@ -375,8 +388,15 @@ class Horde_Kolab_FreeBusy {
 
         $db_owner = $this->_getDbOwner();
 
+        try {
+            $owner_server = $db_owner->getFreebusyServer();
+        } catch (Horde_Kolab_FreeBusy_Exception $e) {
+            // May be unknown and present on another remote server.
+            return;
+        }
+
         /* Check if we are on the right server and redirect if appropriate */
-        if ($db_owner->getFreebusyServer() && $db_owner->getFreebusyServer() != $server) {
+        if ($owner_server && $owner_server != $server) {
 
             if ($trigger) {
                 $path = sprintf('/trigger/%s/%s.' . ($extended)?'pxfb':'pfb',
@@ -385,20 +405,20 @@ class Horde_Kolab_FreeBusy {
                 $path = sprintf('/%s.' . ($extended)?'xfb':'ifb', urlencode($db_owner->getPrimaryId()));
             }
 
-            $redirect = $db_owner->getFreebusyServer() . $path;
+            $redirect = $owner_server . $path;
             Horde::logMessage(sprintf("URL %s indicates remote free/busy server since we only offer %s. Redirecting.", 
-                                      $db_owner->getFreebusyServer(), $server), __FILE__,
+                                      $owner_server, $server), __FILE__,
                               __LINE__, PEAR_LOG_ERR);
             if ($do_redirect) {
                 header("Location: $redirect");
             } else {
                 header("X-Redirect-To: $redirect");
                 $redirect = 'https://' . urlencode($user->getId()) . ':' . urlencode(Auth::getCredential('password'))
-                    . '@' . $db_owner->getFreebusyServer() . $path;
+                    . '@' . $owner_server . $path;
                 if (!@readfile($redirect)) {
                     $message = sprintf(_("Unable to read free/busy information from %s"), 
                                        'https://' . urlencode($user->getPrimaryId()) . ':XXX'
-                                       . '@' . $db_owner->getFreebusyServer() . $_SERVER['REQUEST_URI']);
+                                       . '@' . $owner_server . $_SERVER['REQUEST_URI']);
                     return PEAR::raiseError($message);
                 }
             }
@@ -415,19 +435,35 @@ class Horde_Kolab_FreeBusy {
      */
     private function _generate($resource)
     {
+        global $conf;
+
         require_once 'Horde/Kolab/FreeBusy/Export/Freebusy.php';
         require_once 'Horde/Kolab/FreeBusy/Export/Freebusy/Backend.php';
         require_once 'Horde/Kolab/FreeBusy/Export/Freebusy/Backend/Kolab.php';
         require_once 'Horde/Kolab/FreeBusy/Export/Freebusy/Base.php';
-        require_once 'Horde/Kolab/FreeBusy/Export/Freebusy/Fwthree.php';
         require_once 'Horde/Kolab/FreeBusy/Export/Freebusy/Decorator/Log.php';
+        require_once 'Horde/Kolab/FreeBusy/Helper/Freebusy/StatusMap.php';
+        require_once 'Horde/Kolab/FreeBusy/Helper/Freebusy/StatusMap/Default.php';
+        require_once 'Horde/Kolab/FreeBusy/Helper/Freebusy/StatusMap/Config.php';
         require_once 'Horde/Kolab/FreeBusy/Logger.php';
 
+        $params = array(
+            'request_time' => $this->_getRequest()->getServer('REQUEST_TIME')
+        );
+        if (isset($conf['fb']['future_days'])) {
+            $params['future_days'] = $conf['fb']['future_days'];
+        }
+        if (!empty($conf['fb']['status_map'])) {
+            $params['status_map'] = new Horde_Kolab_FreeBusy_Helper_FreeBusy_StatusMap_Config(
+                $conf['fb']['status_map']
+            );
+        }
+
         $export = new Horde_Kolab_FreeBusy_Export_Freebusy_Decorator_Log(
             new Horde_Kolab_FreeBusy_Export_Freebusy_Base(
                 new Horde_Kolab_FreeBusy_Export_Freebusy_Backend_Kolab(),
                 $resource,
-                $this->_getRequest()
+                $params
             ),
             new Horde_Kolab_FreeBusy_Logger()
         );
@@ -471,7 +507,7 @@ class Horde_Kolab_FreeBusy {
      *
      * @return Horde_Kolab_FreeBusy_Resource The calendar resource.
      */
-    private function _getResource()
+    private function _getResource($name = null, $owner = null)
     {
         /* Now we really need the free/busy library */
         require_once 'Horde/Kolab/FreeBusy/Imap.php';
@@ -488,12 +524,16 @@ class Horde_Kolab_FreeBusy {
         require_once 'Horde/Kolab/FreeBusy/Logger.php';
 
         $imap = new Horde_Kolab_FreeBusy_Imap();
-        $imap->connect($this->_getImapFolder()->getResourceId());
+        if (empty($name)) {
+            $imap->connect($this->_getImapFolder()->getResourceId());
+        } else {
+            $imap->connect($this->_getNamedImapFolder($name)->getResourceId());
+        }
 
         return new Horde_Kolab_FreeBusy_Resource_Event_Decorator_Log(
             new Horde_Kolab_FreeBusy_Resource_Event_Decorator_Mcache(
                 new Horde_Kolab_FreeBusy_Resource_Event_Fwthree(
-                    $imap, $this->_getDbOwner()
+                    $imap, $this->_getDbOwner($owner)
                 )
             ),
             new Horde_Kolab_FreeBusy_Logger()
@@ -509,22 +549,37 @@ class Horde_Kolab_FreeBusy {
         );
     }
 
+    private function _getNamedImapFolder($name)
+    {
+        require_once 'Horde/Kolab/FreeBusy/Params/Freebusy/Resource/Kolab.php';
+        require_once 'Horde/Kolab/FreeBusy/Params/Owner.php';
+        require_once 'Horde/Kolab/FreeBusy/Params/Freebusy/Folder.php';
+        require_once 'Horde/Kolab/FreeBusy/Params/Freebusy/Folder/Named.php';
+        return new Horde_Kolab_FreeBusy_Params_Freebusy_Resource_Kolab(
+            $this->_getDbUser(),
+            new Horde_Kolab_FreeBusy_Params_Freebusy_Folder_Named(
+                $name
+            )
+        );
+    }
+
     private function _getAccess()
     {
         if ($this->_access === null) {
             require_once 'Horde/Kolab/FreeBusy/Params/User.php';
             require_once 'Horde/Kolab/FreeBusy/Params/Owner.php';
-            require_once 'Horde/Kolab/FreeBusy/Params/Freebusy/Owner.php';
+            require_once 'Horde/Kolab/FreeBusy/Params/Owner/Request.php';
             require_once 'Horde/Kolab/FreeBusy/Params/Freebusy/Folder.php';
+            require_once 'Horde/Kolab/FreeBusy/Params/Freebusy/Folder/Request.php';
 
             $this->_access = array(
                 new Horde_Kolab_FreeBusy_Params_User(
                     $this->_getRequest()
                 ),
-                new Horde_Kolab_FreeBusy_Params_Freebusy_Owner(
+                new Horde_Kolab_FreeBusy_Params_Owner_Request(
                     $this->_getRequest()
                 ),
-                new Horde_Kolab_FreeBusy_Params_Freebusy_Folder(
+                new Horde_Kolab_FreeBusy_Params_Freebusy_Folder_Request(
                     $this->_getRequest()
                 )
             );
@@ -541,10 +596,17 @@ class Horde_Kolab_FreeBusy {
         return $this->_request;
     }
 
-    private function _getDbOwner()
+    private function _getDbOwner($owner_name = null)
     {
         list($user, $owner, $folder) = $this->_getAccess();
-        if ($this->_db_owner === null) {
+        if (!empty($owner_name)) {
+            require_once 'Horde/Kolab/FreeBusy/Params/Owner.php';
+            require_once 'Horde/Kolab/FreeBusy/Params/Owner/Named.php';
+            $owner = new Horde_Kolab_FreeBusy_Params_Owner_Named(
+                $owner_name
+            );
+        }
+        if ($this->_db_owner === null || !empty($owner_name)) {
             require_once 'Horde/Kolab/FreeBusy/UserDb.php';
             require_once 'Horde/Kolab/FreeBusy/UserDb/Kolab.php';
             require_once 'Horde/Kolab/FreeBusy/UserDb/User.php';
@@ -588,7 +650,7 @@ class Horde_Kolab_FreeBusy {
         return $this->_db_user;
     }
 
-    public function _getCache()
+    public function _getCache($owner_name = null)
     {
         global $conf;
 
@@ -604,7 +666,11 @@ class Horde_Kolab_FreeBusy {
         }
 
         /* Load the cache class now */
+        require_once 'Horde/Kolab/FreeBusy/Logger.php';
         require_once 'Horde/Kolab/FreeBusy/Cache.php';
+        require_once 'Horde/Kolab/FreeBusy/Cache/Acl.php';
+        require_once 'Horde/Kolab/FreeBusy/Cache/Acl/Base.php';
+        require_once 'Horde/Kolab/FreeBusy/Cache/Partial.php';
         require_once 'Horde/Kolab/FreeBusy/Cache/Structure.php';
         require_once 'Horde/Kolab/FreeBusy/Cache/Structure/Base.php';
         require_once 'Horde/Kolab/FreeBusy/Cache/Structure/Decorator/Log.php';
@@ -616,7 +682,7 @@ class Horde_Kolab_FreeBusy {
                 ),
                 new Horde_Kolab_FreeBusy_Logger()
             ),
-            $this->_getDbOwner()
+            $this->_getDbOwner($owner_name)
         );
     }
 }
