@@ -2,7 +2,7 @@
 /**
  * @package Kolab_Storage
  *
- * $Horde: framework/Kolab_Storage/lib/Horde/Kolab/Storage/Data.php,v 1.5.2.3 2008/11/07 13:00:19 wrobel Exp $
+ * $Horde: framework/Kolab_Storage/lib/Horde/Kolab/Storage/Data.php,v 1.5.2.6 2011/07/12 09:13:01 wrobel Exp $
  */
 
 /** Data caching for Kolab **/
@@ -12,9 +12,9 @@ require_once 'Horde/Kolab/Storage/Cache.php';
  * The Kolab_Data class represents a data type in an IMAP folder on the Kolab
  * server.
  *
- * $Horde: framework/Kolab_Storage/lib/Horde/Kolab/Storage/Data.php,v 1.5.2.3 2008/11/07 13:00:19 wrobel Exp $
+ * $Horde: framework/Kolab_Storage/lib/Horde/Kolab/Storage/Data.php,v 1.5.2.6 2011/07/12 09:13:01 wrobel Exp $
  *
- * Copyright 2004-2008 The Horde Project (http://www.horde.org/)
+ * Copyright 2004-2009 The Horde Project (http://www.horde.org/)
  *
  * See the enclosed file COPYING for license information (LGPL). If you
  * did not receive this file, see http://www.fsf.org/copyleft/lgpl.html.
@@ -147,33 +147,20 @@ class Kolab_Data {
      */
     function _getCacheKey()
     {
-        if ($this->_cache_cyrus_optimize) {
-            $search_prefix = 'INBOX/';
-
-            $pos = strpos($this->_folder->name, $search_prefix);
-            if ($pos !== false && $pos == 0) {
-                $key = 'user/' . Auth::getBareAuth() . '/'
-                           . substr($this->_folder->name,
-                                    strlen($search_prefix))
-                           . $this->_type_key;
-            } else {
-                $key = $this->_folder->name;
-            }
-        } else {
-            $key = $this->_folder->getOwner() . '/' . $this->_folder->name;
-        }
-        return $key;
+        return $this->_folder->getOwner() . '/' . $this->_folder->getSubpath()
+            . $this->_type_key;
     }
 
     /**
      * Delete the specified message from this folder.
      *
-     * @param  string $object_uid Id of the message to be deleted.
+     * @param  string  $object_uid Id of the message to be deleted.
+     * @param  boolean $expunge    Forces folder expunging after delete
      *
      * @return boolean|PEAR_Error True is successful, false if the
      *                            message does not exist.
      */
-    function delete($object_uid)
+    function delete($object_uid, $expunge = true)
     {
         if (!$this->objectUidExists($object_uid)) {
             return false;
@@ -185,7 +172,7 @@ class Kolab_Data {
             return false;
         }
 
-        $result = $this->_folder->deleteMessage($id);
+        $result = $this->_folder->deleteMessage($id, true, $expunge);
         if (is_a($result, 'PEAR_Error')) {
             return $result;
         }
@@ -201,15 +188,17 @@ class Kolab_Data {
     /**
      * Delete all messages from the current folder.
      *
+     * @param  boolean $expunge Forces folder expunging after delete
+     *
      * @return boolean|PEAR_Error True if successful.
      */
-    function deleteAll()
+    function deleteAll($expunge = true)
     {
         if (empty($this->_cache->uids)) {
             return true;
         }
         foreach ($this->_cache->uids as $id => $object_uid) {
-            $result = $this->_folder->deleteMessage($id, false);
+            $result = $this->_folder->deleteMessage($id, false, $expunge);
             if (is_a($result, 'PEAR_Error')) {
                 return $result;
             }
