@@ -2,7 +2,7 @@
 /**
  * @package Kolab_Storage
  *
- * $Horde: framework/Kolab_Storage/lib/Horde/Kolab/Storage/Folder.php,v 1.7.2.21 2010-06-22 09:31:39 wrobel Exp $
+ * $Horde: framework/Kolab_Storage/lib/Horde/Kolab/Storage/Folder.php,v 1.7.2.26 2011/09/02 10:45:58 wrobel Exp $
  */
 
 /** We need the current user session. */
@@ -59,7 +59,7 @@ define('HORDE_ANNOT_SHARE_ATTR', '/vendor/horde/share-');
  * The Kolab_Folder class represents an IMAP folder on the Kolab
  * server.
  *
- * $Horde: framework/Kolab_Storage/lib/Horde/Kolab/Storage/Folder.php,v 1.7.2.21 2010-06-22 09:31:39 wrobel Exp $
+ * $Horde: framework/Kolab_Storage/lib/Horde/Kolab/Storage/Folder.php,v 1.7.2.26 2011/09/02 10:45:58 wrobel Exp $
  *
  * Copyright 2004-2009 The Horde Project (http://www.horde.org/)
  *
@@ -180,6 +180,20 @@ class Kolab_Folder {
      */
     var $tainted = false;
 
+    /**
+     * The user rights.
+     *
+     * @var string
+     */
+    var $_my_rights;
+
+    /**
+     * The complete folder rights.
+     *
+     * @var array
+     */
+    var $_acl;
+
     /**
      * Creates a Kolab Folder representation.
      *
@@ -374,6 +388,7 @@ class Kolab_Folder {
                 $this->new_name = null;
                 $this->_title   = null;
                 $this->_owner   = null;
+                $this->_subpath = null;
             }
         }
 
@@ -388,7 +403,7 @@ class Kolab_Folder {
 
         /** Handle the folder type */
         $folder_type = $this->_type . ($this->_default ? '.default' : '');
-        if ($this->_type_annotation != $folder_type) {
+        if ($this->_owner == Auth::getAuth() && $this->_type_annotation != $folder_type) {
             $result = $this->_setAnnotation(KOLAB_ANNOT_FOLDER_TYPE, $folder_type);
             if (is_a($result, 'PEAR_Error')) {
                 $this->_type = null;
@@ -410,19 +425,38 @@ class Kolab_Folder {
                         if (is_a($result, 'PEAR_Error')) {
                             return $result;
                         }
+                        unset($params['xfbaccess']);
                     }
                     if (isset($params['fbrelevance'])) {
                         $result = $this->setFbrelevance($params['fbrelevance']);
                         if (is_a($result, 'PEAR_Error')) {
                             return $result;
                         }
+                        unset($params['fbrelevance']);
                     }
+                    if (isset($params['activesync'])) {
+                        $result = $this->setActiveSyncDeviceData($params['activesync'], 'FOLDER');
+                        if (is_a($result, 'PEAR_Error')) {
+                            return $result;
+                        }
+                        unset($params['activesync']);
+                    }
+                    if (empty($params)) {
+                        continue;
+                    }
+                    $value = serialize($params);
                 }
 
                 // setAnnotation apparently does not suppoort UTF-8 nor any special characters
                 $store = base64_encode($value);
                 if ($key == 'desc') {
-                    $entry = '/comment';
+                    if ($this->_owner == Auth::getAuth()) {
+                        $entry = '/comment';
+                    } else {
+                        continue;
+                    }
+                } else if ($key == 'params' && $this->_owner != Auth::getAuth()) {
+                    continue;
                 } else {
                     $entry = HORDE_ANNOT_SHARE_ATTR . $key;
                 }
@@ -435,7 +469,7 @@ class Kolab_Folder {
         }
 
         /** Now save the folder permissions */
-        if (isset($this->_perms)) {
+        if ($this->_owner == Auth::getAuth() && isset($this->_perms)) {
             $result = $this->_perms->save();
             if (is_a($result, 'PEAR_Error')) {
                 return $result;
@@ -728,10 +762,11 @@ class Kolab_Folder {
      *
      * @param  string  $id      IMAP id of the message to be deleted.
      * @param  boolean $trigger Should the folder be triggered?
+     * @param  boolean $expunge Should the folder be expunged?
      *
      * @return boolean|PEAR_Error True if successful.
      */
-    function deleteMessage($id, $trigger = true)
+    function deleteMessage($id, $trigger = true, $expunge = true)
     {
         $session = &Horde_Kolab_Session::singleton();
         $imap = &$session->getImap();
@@ -750,9 +785,11 @@ class Kolab_Folder {
             return $result;
         }
 
-        $result = $imap->expunge();
-        if (is_a($result, 'PEAR_Error')) {
-            return $result;
+        if ($expunge) {
+            $result = $imap->expunge();
+            if (is_a($result, 'PEAR_Error')) {
+                return $result;
+            }
         }
 
         if ($trigger) {
@@ -1090,12 +1127,27 @@ class Kolab_Folder {
     function parseMessage($id, $mime_type, $parse_headers = true,
                           $formats = array('XML'))
     {
+        global $conf;
+
         $session = &Horde_Kolab_Session::singleton();
         $imap = &$session->getImap();
         if (is_a($imap, 'PEAR_Error')) {
             return $imap;
         }
 
+        if (!empty($conf['kolab']['imap']['size_limit'])) {
+            $size = $imap->getMessageSize($id);
+            if (is_a($size, 'PEAR_Error')) {
+                return PEAR::raiseError(sprintf(_("Failed retrieving the message size for message ID %s. Original error: %s."),
+                                                $id, $size->getMessage()));
+            }
+            if ($size > $conf['kolab']['imap']['size_limit']) {
+                return PEAR::raiseError(sprintf(_("Message size %s for message ID %s exceeds the limit (%s)."),
+                                                $size, $id, $conf['kolab']['imap']['size_limit']));
+            }
+        }
+
+
         $raw_headers = $imap->getMessageHeader($id);
         if (is_a($raw_headers, 'PEAR_Error')) {
             return PEAR::raiseError(sprintf(_("Failed retrieving the message with ID %s. Original error: %s."),
@@ -1354,43 +1406,56 @@ class Kolab_Folder {
      */
     function getACL()
     {
-        global $conf;
+        if (!isset($this->_acl)) {
+            global $conf;
 
-        $session = &Horde_Kolab_Session::singleton();
-        $imap = &$session->getImap();
-        if (is_a($imap, 'PEAR_Error')) {
-            return $imap;
-        }
-
-        if (!empty($conf['kolab']['imap']['no_acl'])) {
-            $acl = array();
-            $acl[Auth::getAuth()] = 'lrid';
-            return $acl;
-        }
-
-        $acl = $imap->getACL($this->name);
-
-        /*
-         * Check if the getPerm comes from the owner in this case we
-         * can use getACL to have all the right of the share Otherwise
-         * we just ask for the right of the current user for a folder
-         */
-        if ($this->getOwner() == Auth::getAuth()) {
-            return $acl;
-        } else {
-            if (!is_a($acl, 'PEAR_Error')) {
-                return $acl;
+            $session = &Horde_Kolab_Session::singleton();
+            $imap = &$session->getImap();
+            if (is_a($imap, 'PEAR_Error')) {
+                return $imap;
             }
 
-            $my_rights = $imap->getMyrights($this->name);
-            if (is_a($my_rights, 'PEAR_Error')) {
-                return $my_rights;
+            if (!empty($conf['kolab']['imap']['no_acl'])) {
+                $this->_acl = array();
+                $this->_acl[Auth::getAuth()] = 'lrid';
+            } else {
+                $my_rights = $this->getMyRights();
+                if (is_a($my_rights, 'PEAR_Error')) {
+                    return $my_rights;
+                }
+
+                $this->_acl = array();
+                $this->_acl[Auth::getAuth()] = $my_rights;
+
+                if (strpos($my_rights, 'a') !== false) {
+                    $acl = $imap->getACL($this->name);
+                    if (!is_a($acl, 'PEAR_Error')) {
+                        $this->_acl = $acl;
+                    }
+                }
+            }
+        }
+        return $this->_acl;
+    }
+
+    function getMyRights()
+    {
+        if (!isset($this->_my_rights)) {
+            global $conf;
+
+            $session = &Horde_Kolab_Session::singleton();
+            $imap = &$session->getImap();
+            if (is_a($imap, 'PEAR_Error')) {
+                return $imap;
             }
 
-            $acl = array();
-            $acl[Auth::getAuth()] = $my_rights;
-            return $acl;
+            if (!empty($conf['kolab']['imap']['no_acl'])) {
+                $this->_my_rights = 'lrid';
+            } else {
+                $this->_my_rights = $imap->getMyrights($this->name);
+            }
         }
+        return $this->_my_rights;
     }
 
     /**
@@ -1405,6 +1470,9 @@ class Kolab_Folder {
     {
         global $conf;
 
+	$this->_my_rights = null;
+	$this->_acl = null;
+
         $session = &Horde_Kolab_Session::singleton();
         $imap = &$session->getImap();
         if (is_a($imap, 'PEAR_Error')) {
@@ -1446,6 +1514,9 @@ class Kolab_Folder {
     {
         global $conf;
 
+	$this->_my_rights = null;
+	$this->_acl = null;
+
         $session = &Horde_Kolab_Session::singleton();
         $imap = &$session->getImap();
         if (is_a($imap, 'PEAR_Error')) {
@@ -1642,4 +1713,132 @@ class Kolab_Folder {
         return $this->_setAnnotation(KOLAB_ANNOT_ROOT . 'pxfb-readable-for',
                                      $value);
     }
+
+    /**
+     * Get the active sync settings for this folder.
+     *
+     * @return array  Array containing the active sync information.
+     */
+    function getActiveSync()
+    {
+        $imap = Horde_Kolab_Session::singleton()->getImap();
+        if (is_a($imap, 'PEAR_Error')) {
+            return $imap;
+        }
+        $raw = $imap->getAnnotation(
+            KOLAB_ANNOT_ROOT . 'activesync', 'value.priv', $this->name
+        );
+        $local = json_decode(base64_decode($raw), true);
+        $result = array(
+            'DEVICE' => array(),
+            'FOLDER' => array(),
+        );
+        if ($this->name != 'INBOX') {
+            $raw = $imap->getAnnotation(
+                KOLAB_ANNOT_ROOT . 'activesync', 'value.priv', 'INBOX'
+            );
+            $global = json_decode(base64_decode($raw), true);
+            if (is_array($global) && is_array($local)) {
+                $result = array(
+                    'DEVICE' => isset($global['DEVICE']) ? $global['DEVICE'] : array(),
+                    'FOLDER' => isset($local['FOLDER']) ? $local['FOLDER'] : array(),
+                );
+            } elseif (is_array($global)) {
+                $result = array(
+                    'DEVICE' => isset($global['DEVICE']) ? $global['DEVICE'] : array(),
+                    'FOLDER' => array()
+                );
+            } elseif (is_array($local)) {
+                $result = array(
+                    'DEVICE' => array(),
+                    'FOLDER' => isset($local['FOLDER']) ? $local['FOLDER'] : array(),
+                );
+            }
+        } elseif (is_array($local)) {
+            $result = $local;
+        }
+        $result['NAMESPACE'] = $this->_list->namespace->matchNamespace($this->name)->getType();
+        return $result;
+    }
+
+    /**
+     * Delete an active sync device for this folder.
+     *
+     * @param string $id The id of the device.
+     *
+     * @return mixed  True on success or a PEAR_Error.
+     */
+    function deleteActiveSyncDevice($id)
+    {
+        $imap = Horde_Kolab_Session::singleton()->getImap();
+        if (is_a($imap, 'PEAR_Error')) {
+            return $imap;
+        }
+        $raw = $imap->getAnnotation(
+            KOLAB_ANNOT_ROOT . 'activesync', 'value.priv', $this->name
+        );
+        $result = json_decode(base64_decode($raw), true);
+        if (is_a($result, 'PEAR_Error')) {
+            return $result;
+        }
+        if (!is_array($result)) {
+            return true;
+        }
+        unset($result['DEVICE'][$id]);
+        $result = $imap->setAnnotation(
+            KOLAB_ANNOT_ROOT . 'activesync',
+            array('value.priv' => base64_encode(json_encode($result))),
+            $this->name
+        );
+        if (is_a($result, 'PEAR_Error')) {
+            return $result;
+        }
+        return true;
+    }
+
+    /**
+     * Set the active sync annotation.
+     *
+     * @param string $data  The data to store in the annotation.
+     * @param string $type  The type of the data (DEVICE|FOLDER).
+     *
+     * @return mixed  True on success or a PEAR_Error.
+     */
+    function setActiveSyncDeviceData($data, $type = 'DEVICE')
+    {
+        $imap = Horde_Kolab_Session::singleton()->getImap();
+        if (is_a($imap, 'PEAR_Error')) {
+            return $imap;
+        }
+        $raw = $imap->getAnnotation(
+            KOLAB_ANNOT_ROOT . 'activesync', 'value.priv', $this->name
+        );
+        $old = json_decode(base64_decode($raw), true);
+        if (is_a($old, 'PEAR_Error')) {
+            return $data;
+        }
+        if (!is_array($old)) {
+            $old = array();
+        }
+
+        $new_type = isset($old[$type]) ? $old[$type] : array();
+        $data_type = isset($data[$type]) ? $data[$type] : array();
+        foreach ($data_type as $id => $settings) {
+            foreach ($settings as $key => $value) {
+                $new_type[$id][$key] = $value;
+            }
+        }
+        $new = $old;
+        $new[$type] = $new_type;
+        $result = $imap->setAnnotation(
+            KOLAB_ANNOT_ROOT . 'activesync',
+            array('value.priv' => base64_encode(json_encode($new))),
+            $this->name
+        );
+
+        if (is_a($result, 'PEAR_Error')) {
+            return $result;
+        }
+        return true;
+    }
 }
