@@ -2,7 +2,7 @@
 /**
  * @package Kolab_Storage
  *
- * $Horde: framework/Kolab_Storage/lib/Horde/Kolab/Storage/List.php,v 1.3.2.10 2010-06-25 04:53:49 wrobel Exp $
+ * $Horde: framework/Kolab_Storage/lib/Horde/Kolab/Storage/List.php,v 1.3.2.11 2011/07/21 13:38:57 wrobel Exp $
  */
 
 /** Kolab IMAP folder representation. **/
@@ -22,7 +22,7 @@ require_once 'Horde/Kolab/Storage/Namespace/Element/SharedWithPrefix.php';
  * The Kolab_List class represents all IMAP folders on the Kolab
  * server visible to the current user.
  *
- * $Horde: framework/Kolab_Storage/lib/Horde/Kolab/Storage/List.php,v 1.3.2.10 2010-06-25 04:53:49 wrobel Exp $
+ * $Horde: framework/Kolab_Storage/lib/Horde/Kolab/Storage/List.php,v 1.3.2.11 2011/07/21 13:38:57 wrobel Exp $
  *
  * Copyright 2007-2009 The Horde Project (http://www.horde.org/)
  *
@@ -124,11 +124,15 @@ class Kolab_List {
     {
         static $list;
 
-        if (!isset($list) &&
-            !empty($GLOBALS['conf']['kolab']['imap']['cache_folders'])) {
-            require_once 'Horde/SessionObjects.php';
-            $session = &Horde_SessionObjects::singleton();
-            $list = $session->query('kolab_folderlist');
+        if (!$destruct) {
+            if (isset($list[Auth::getAuth()])) {
+                return $list[Auth::getAuth()];
+            }
+            if (!empty($GLOBALS['conf']['kolab']['imap']['cache_folders'])) {
+                require_once 'Horde/SessionObjects.php';
+                $session = &Horde_SessionObjects::singleton();
+                $list[Auth::getAuth()] = $session->query('kolab_folderlist');
+            }
         }
 
         if (empty($list[Auth::getAuth()]) || $destruct) {
@@ -136,7 +140,7 @@ class Kolab_List {
         }
 
         if (!empty($GLOBALS['conf']['kolab']['imap']['cache_folders'])) {
-            register_shutdown_function(array(&$list, 'shutdown'));
+            register_shutdown_function(array($list[Auth::getAuth()], 'shutdown'));
         }
 
         return $list[Auth::getAuth()];
