@@ -2,9 +2,9 @@
 /**
  * The Horde_UI_VarRenderer_html:: class renders variables to HTML.
  *
- * $Horde: framework/UI/UI/VarRenderer/html.php,v 1.98.2.39 2008/08/11 16:31:50 jan Exp $
+ * $Horde: framework/UI/UI/VarRenderer/html.php,v 1.98.2.42 2009/09/14 07:22:07 jan Exp $
  *
- * Copyright 2003-2008 The Horde Project (http://www.horde.org/)
+ * Copyright 2003-2009 The Horde Project (http://www.horde.org/)
  *
  * See the enclosed file LICENSE for license information (LGPL).
  *
@@ -157,10 +157,7 @@ class Horde_UI_VarRenderer_html extends Horde_UI_VarRenderer {
     function _renderVarInput_image($form, &$var, &$vars)
     {
         $varname = htmlspecialchars($var->getVarName());
-        $image = $var->getValue($vars);
-
-        /* Check if existing image data is being loaded. */
-        $var->type->loadImageData($image);
+        $image = $var->type->getImage($vars, $var);
 
         Horde::addScriptFile('image.js', 'horde', true);
         $graphics_dir = $GLOBALS['registry']->getImageDir('horde');
@@ -170,13 +167,11 @@ class Horde_UI_VarRenderer_html extends Horde_UI_VarRenderer {
 
         /* Check if there is existing img information stored. */
         if (isset($image['img'])) {
-            /* Hidden tag to store the preview image filename. */
+            /* Hidden tag to store the preview image id. */
             $html = sprintf('<input type="hidden" name="%s" id="%s" value="%s" />',
-                            $varname . '[img]',
-                            $varname . '[img]',
-                            @htmlspecialchars($image['img'], ENT_QUOTES, $this->_charset));
-            /* Unserialize the img information to get the full array. */
-            $image['img'] = @unserialize($image['img']);
+                            $varname . '[hash]',
+                            $varname . '[hash]',
+                            $var->type->getRandomId());
         }
 
         /* Output MAX_FILE_SIZE parameter to limit large files. */
@@ -564,16 +559,25 @@ class Horde_UI_VarRenderer_html extends Horde_UI_VarRenderer {
         global $registry, $browser;
 
         $varname = @htmlspecialchars($var->getVarName(), ENT_QUOTES, $this->_charset);
-        $html = '<table cellspacing="0"><tr><td>' .
-            '<input type="text" size="10" maxlength="7" name="' .
-            $varname . '" id="' . $varname .
-            '" value="' . @htmlspecialchars($var->getValue($vars), ENT_QUOTES, $this->_charset) . '" /></td>';
+        $color = $var->getValue($vars);
+        if ($color) {
+            require_once 'Horde/Image.php';
+            $style = ' style="background-color:' . $color . ';color:'
+                . (Horde_Image::brightness($color) < 128 ? '#fff' : '#000') . '"';
+        } else {
+            $style = '';
+        }
+        $html = '<table cellspacing="0"><tr><td>'
+            . '<input type="text" size="10" maxlength="7" name="'
+            . $varname . '" id="' . $varname . '"' . $style
+            . ' value="' . @htmlspecialchars($color, ENT_QUOTES, $this->_charset)
+            . '" /></td>';
         if ($browser->hasFeature('javascript')) {
             Horde::addScriptFile('prototype.js', 'horde', true);
             Horde::addScriptFile('colorpicker.js', 'horde', true);
             $html .= '<td>'
                 . Horde::link('#', _("Color Picker"), '', '',
-                              'new ColorPicker({ color: \'' . htmlspecialchars($var->getValue($vars)) . '\', offsetParent: Event.element(event), update: [[\'' . $varname . '\', \'value\']] }); return false;')
+                              'new ColorPicker({ color: \'' . htmlspecialchars($color) . '\', offsetParent: Event.element(event), update: [[\'' . $varname . '\', \'value\'], [\'' . $varname . '\', \'background\']] }); return false;')
                 . Horde::img('colorpicker.png', _("Color Picker"), 'height="16"', $registry->getImageDir('horde')) . '</a></td>';
         }
         return $html . '</tr></table>';
@@ -1136,11 +1140,6 @@ EOT;
         /* Check if existing image data is being loaded. */
         $var->type->loadImageData($image);
 
-        if (isset($image['img'])) {
-            /* Unserialize the img information to get the full array. */
-            $image['img'] = @unserialize($image['img']);
-        }
-
         if (empty($image['img'])) {
             return '';
         }
